:mod:`art.preprocessing.audio`
==============================
.. automodule:: art.preprocessing.audio

L-Filter
--------
.. autoclass:: LFilter
   :members:
   :special-members:

LFilter - PyTorch
-----------------
.. autoclass:: LFilterPyTorch
   :members:
   :special-members:
